<?php
/**
 * A base, highly extendable, calendar class.
 * 
 * This class defines a custom calendar with all the required basic initialization methods required for successful
 * expansion of further, more specific types of calendars. 
 * 
 * @package Calendar
 * @category Calendars
 * @author Misa Brezanac <brezanac@gmail.com>
 * @copyright http://creativecommons.org/licenses/by-nc-sa/3.0/rs/
*/
class Calendar {
    /**
     * Month of the year for which the calendar is to be generated.
    */
    protected $month;

    /**
     * The year for which the calendar is to be generated.
    */
    protected $year;

    /**
     * Weeks offset representing the true first day of the week [if set to zero it will be Sunday].
    */
    private $weekOffset;
    
    /**
     * Contains the name of the CSS class that will be used for calendar rendering.
    */
    protected $className;
    
    /**
     * Current month's number of days.
    */
    protected $daysInMonth;

    /**
     * The numerical representation of the week's day that represents the first day of the month 
     * [0->Sunday, 6->Saturday]
    */
    protected $firstWeekDayOfMonth;

    /**
     * How many weeks are in the current $month?
    */
    protected $weeksInMonth;

    /**
     * An array containing all the calendar positions required for the base calendar 'buildCalendar()' method. 
    */
    protected $calendar;
    
    /**
     * Stores the current day during checkup operations and such...i.e. during calendar rendering etc. 
    */
    protected $day;
    
    /**
     * Temporary variable required during the process of calendar building.
    */
    private $tempDays;
    
    /**
     * Previous year used for quick calendar navigation.
    */
    protected $previousYear;
    
    /**
     * Previous month used for quick calendar navigation.
    */
    protected $previousMonth;
    
    /**
     * Next year used for quick calendar navigation.
    */
    protected $nextYear;
    
    /**
     * Next month used for quick calendar navigation.
    */
    protected $nextMonth;

    /**
     * Calendar class constructor. 
     * 
     * @param string $className The CSS class name of the calendar
     * @param integer $month The 'month' part of the date
     * @param integer $year The 'year' part of the date
     * @param integer $weekOffset The first day of week adding up to Sunday -> '0'. Used only in the base class.
    */
    function __construct ( $className = 'calendar', $month = '', $year = '', $weekOffset = 0) {
        if ( !(intval($month) > 0) || !(intval($year) > 0) ) {
            $this->month = date('n');
            $this->year = date('Y');
            $this->weekOffset = 0;
        } else if(($year > UNIX_TIMESTAMP_HIGH_YEAR) || ($year < UNIX_TIMESTAMP_LOW_YEAR)){ 
            die("Година мора бити у опсегу од: <strong>".UNIX_TIMESTAMP_LOW_YEAR.".</strong> до: <strong>".UNIX_TIMESTAMP_HIGH_YEAR).".</strong>";
        }else {
            $this->month = $month;
            $this->year = $year;
            $this->weekOffset = $weekOffset;
        }
        $this->className = $className;
        
        /*
         * Calculates some initial stuff.
        */
        $this->buildCalendar();
    }

    /**
     * Calculates some basic data required for building almost all types of calendars. 
    */
    public function buildCalendar () {
        /**
         * Number of days in current month.  
        */
        $this->daysInMonth = date("t", mktime(0, 0, 0, $this->month, 1, $this->year));
        /*
         * Ranges from 0 representing Sunday to 6 representing Saturday
        */
        $this->firstWeekDayOfMonth = date("w", mktime(0, 0, 0, $this->month, 1, $this->year));
        $this->tempDays = $this->firstWeekDayOfMonth + $this->daysInMonth;
        /*
         * How many weeks in current month? 
        */
        $this->weeksInMonth = ceil($this->tempDays / 7);
        
        /*
         * The following variables are used for the quick calendar navigation at the top. 
         * The date 15th was choosen to avoid the problem of variable number of days in month.
        */
        list($this->previousMonth, $this->previousYear) = explode(",", date("n,Y", mktime(12, 0, 0, $this->month, 15, $this->year) - 2592000));
        list($this->nextMonth, $this->nextYear) = explode(",", date("n,Y", mktime(12, 0, 0, $this->month, 15, $this->year) + 2592000));
    }
    
    /**
     * Renders the base class calendar.
     * 
     * @todo The actual rendering routine needs to be completed. 
     * 
    */
    public function renderCalendar() { 
        for ( $i = 0; $i < $this->weeksInMonth; $i++ ) {
            for ( $j = 0; $j < 7; $j++ ) {
                $counter++;
                $this->calendar[$i][$j] = $counter;
                
                /*
                 * Offsetting the days in the temporary array. 
                 * There are two types of offsets:
                 * 'firstWeekDayOfMonth' - the neumerical representation of the first week day in month 
                 * [0-Sunday, 6-Saturaday]
                 * 'weekOffset' - the offset that adds to the 'firstWeekDayOfMonth' to form the actual first day in week 
                 * [0-Sunday, 1-Monday...]
                */
                $this->calendar[$i][$j] -= ($this->firstWeekDayOfMonth - $this->weekOffset);
                
                /*
                 * Checking if the current number in the array is within bounds 
                 * [0 > $this->calndar[$i][$j] > $daysInMonth]
                */
                if(($this->calendar[$i][$j] < 1) || ($this->calnder[$i][$j] > $this->daysInMonth)){
                    $this->calendar[$i][$j] = '';   
                }   
            }
        }
        
        /*
         * Now the heavy stuff... the rendering...
         * 
         * NOTICE: Needs to be completed
        */
    }
    /**
     * Renders a response XML for AJAX month preview requests. 
     * 
     * Creates the following structure:
     * <containers>
     *     <container>
     *          <title>The title of the div container which content is to be updated</title>
     *          <content>The updating content</content>
     *     </container>
     * </containers>
     * It depends upon the renderCalendar() method which actaully renders the calendar output.
    */
    public function renderCalendarToXML(){
        header("Content-Type: text/xml"); //sending the content type header (required)
        header("Cache-Control: no-cache, must revalidate"); //preventing local caching
        header("Expires: Mon, 26 Jul 1997 05:00:00 GMT"); //making sure nothing is cached
        echo '<?xml version="1.0" encoding="utf-8"?><containers><container><title>';
        echo $this->className;
        echo '</title><content><![CDATA[';
        echo $this->renderCalendar();
        echo "]]></content></container></containers>"; 
    }
    
    /**
     * Returns the weekday index of the current day [0 -> Sunday, 6 -> Saturday].
     * 
     * @param integer $day The 'day' component of the date
     * @param integer $month The 'month' component of the date
     * @param integer $year The 'year' component of the date
     * @return integer The resulting week index
    */
    protected function findWeekDay($day, $month, $year){
        return date("w", mktime(12, 0, 0, $month, $day, $year));           
    }
    
    /**
     * Performs a check if the current year is a leap year.
     * 
     * @return boolean Is the current year a leap year or not?
    */
    protected function isLeapYear(){
        return !($this->year % 4) && (($this->year % 100) || !($this->year % 400));           
    }
}
?>