<?php
/**
 * A converter class responsible for converting text from cyrillic to latin representation and vice versa.
 * 
 * @package Language
 * @subpackage Converter
 * @category Converters
 * @author Misa Brezanac <brezanac@gmail.com>
 * @copyright http://creativecommons.org/licenses/by-nc-sa/3.0/rs/
*/

class Converter {
    /**
     * The array containig the conversion table which is used during the conversion process.
    */
    private $conversionTable;
    
    /**
     * Which conversion mode is to be used? Allowed values are 'lat_to_cyr' and 'cyr_to_lat' Default is 'lat_to_cyr'.
    */
    private $conversionMode;
    
    /**
     * Holds the text to be converted. 
    */
    private $textToConvert;
    
    /**
     * Class constructor.
    */
    function __construct($convesrionMode = 'lat_to_cyr'){
        $this->conversionMode = $conversionMode;           
    }
    
    /*
     * Loading required characters into the conversion table acording to the given conversion mode
    */
    private function initiateConversionTable(){
        switch($this->conversionMode){
            case 'cyr_to_lat':
                $this->conversionTable = array(
                    //small caps
                    //'a' => 'a',
                    'б' => 'b',
                    'в' => 'v',
                    'г' => 'g',
                    'д' => 'd',
                    'ђ' => 'đ',
                    //'e' => 'е', 
                    'ж' => 'ž', 
                    'з' => 'z',
                    'и' => 'i',
                    //'j' => 'ј',
                    'к' => 'k', 
                    'л' => 'l',
                    'љ' => 'lj',
                    'м' => 'm',
                    'н' => 'n', 
                    'њ' => 'nj',
                    //'o' => 'о',
                    'п' => 'p',
                    'р' => 'r',
                    'с' => 's',
                    'т' => 't',
                    'ћ' => 'ć',
                    'у' => 'u',
                    'ф' => 'f',
                    'х' => 'h',
                    'ц' => 'c',
                    'ч' => 'č',
                    'џ' => 'dž',
                    'ш' => 'š',
                    
                    //large caps
                    //'A' => 'A',
                    'Б' => 'B',
                    'В' => 'V',
                    'Г' => 'G',
                    'Д' => 'D',
                    'Ђ' => 'Đ',
                    //'E' => 'Е',
                    'Ж' => 'Ž',
                    'З' => 'Z',
                    'И' => 'I',
                    //'J' => 'Ј',
                    'К' => 'K',
                    'Л' => 'L',
                    'Љ' => 'Lj',
                    //'M' => 'М',
                    'Н' => 'N',
                    'Њ' => 'Nj',
                    //'O' => 'О',
                    'П' => 'P',
                    'Р' => 'R',
                    'С' => 'S',
                    //'T' => 'Т',
                    'Ћ' => 'Ć',
                    'У' => 'U',
                    'Ф' => 'F',
                    'Х' => 'H',
                    'Ц' => 'C',
                    'Ч' => 'Č',
                    'Џ' => 'Dž',
                    'Ш' => 'Š'   
                );        
            break;
            default:
                $this->conversionTable = array(
                    //small caps
                    //'a' => 'a',
                    'b' => 'б',
                    'v' => 'в',
                    'g' => 'г',
                    'd' => 'д',
                    'đ' => 'ђ',
                    //'e' => 'е', 
                    'ž' => 'ж', 
                    'z' => 'з',
                    'i' => 'и',
                    //'j' => 'ј',
                    'k' => 'к', 
                    'l' => 'л',
                    'lj' => 'љ',
                    'm' => 'м',
                    'n' => 'н', 
                    'nj' => 'њ',
                    //'o' => 'о',
                    'p' => 'п',
                    'r' => 'р',
                    's' => 'с',
                    't' => 'т',
                    'ć' => 'ћ',
                    'u' => 'у',
                    'f' => 'ф',
                    'h' => 'х',
                    'c' => 'ц',
                    'č' => 'ч',
                    'dž' => 'џ',
                    'š' => 'ш',
                    
                    //large caps
                    //'A' => 'A',
                    'B' => 'Б',
                    'V' => 'В',
                    'G' => 'Г',
                    'D' => 'Д',
                    'Đ' => 'Ђ',
                    //'E' => 'Е',
                    'Ž' => 'Ж',
                    'Z' => 'З',
                    'I' => 'И',
                    //'J' => 'Ј',
                    'K' => 'К',
                    'L' => 'Л',
                    'LJ' => 'Љ',
                    //'M' => 'М',
                    'N' => 'Н',
                    'NJ' => 'Њ',
                    //'O' => 'О',
                    'P' => 'П',
                    'R' => 'Р',
                    'S' => 'С',
                    //'T' => 'Т',
                    'Ć' => 'Ћ',
                    'U' => 'У',
                    'F' => 'Ф',
                    'H' => 'Х',
                    'C' => 'Ц',
                    'Č' => 'Ч',
                    'Dž' => 'Џ',
                    'Š' => 'Ш'   
                ); 
        }    
    }
    
    /**
     * Converts the input string (array) into requested format.
     *  
     * The character conversion table is already loaded at this point via the constructor.
     * 
     * @param mixed $textToConvert The text string (array) to convert.  
    */
    public function convert($textToConvert){
        $this->textToConvert = $textToConvert;
        $this->convertedText = $this->textToConvert; //making a working copy 

        self::initiateConversionTable();
        
        foreach($this->conversionTable as $key => $value){
            $this->convertedText = str_replace($key, $value, $this->convertedText);
        }  
        return $this->convertedText;
    }       
}
?>
