<?php
/**
 * Custom exception error handling class.
 * 
 * Extends the native Exception class. It adds multilanguage support and language specific error output.
 * Also it logs errors to the internal log.file.  
 * 
 * @package Exception
 * @subpackage Custom_Exception
 * @category Error handling
 * @author Misa Brezanac <brezanac@gmail.com>
 * @copyright http://creativecommons.org/licenses/by-nc-sa/3.0/rs/
*/
class Custom_Exception extends Exception{
    /**
     * Localized messages array that will be loaded from the language file.
    */
    private $messages = array(); 
    
    /**
     * Localized custom error string sent by the exception initiator.
    */
    private $errorDescription;
    
    /**
     * File handle variable used to contain file handles for opened files.
    */
    private $fileHandle;
    
    /**
     * Temporary string variable containing reported errors.
    */
    private $tempString;
    
    /**
     * The custom exception handling class constructor
     * 
     * @param string $errorDescription The message abbreviation string representing the key of '$messages' array.
    */
    function __construct($errorDescription){
        $this->errorDescription = $errorDescription;
        /*
        * Loading of localized messages from the external file into the $message array, PHP tags are being removed.
        * Although this seems to work it seems there are much nicer ways to deal with this localized page loads...
        * Please stay tuned for more Nobel prize material... :)
        */
        $this->messages = eval(str_replace(array("<?php", "?>"), "", file_get_contents(LANGUAGE_ROOT.DEFAULT_LANGUAGE.".lang.php")));  
    }
    
    /**
    * Notes the custom exception handler message to the log file when DEBUG_MODE is set to true. 
    */
    public function noteMessage(){
        $this->tempString .= "Time: [".date("d.m.Y. H:i:s")."]\n";
        $this->tempString .= "The exception handling routine caught the following error:\n";
        $this->tempString .= "File: ".$this->getFile()."\n";
        $this->tempString .= "Line number: ".$this->getLine()."\n";
        $this->tempString .= "Error description: ".$this->errorDescription."\n"; 
        $this->tempString .= "Error message: ".$this->messages[$this->errorDescription]."\n";
        $this->tempString .= "--------------------------------------\n";
         
        try {
            if(($this->fileHandle = fopen(ERROR_LOG_FILE,"a")) || ($this->fileHandle = fopen(ERROR_LOG_FILE, "w"))){
                fwrite($this->fileHandle, $this->tempString);
                fclose($this->fileHandle);   
            } else {
                throw new Custom_Exception('fs_error_log_file_unable_to_write');
            }
        } catch (Custom_Exception $e) {
            if(DEBUG_MODE)
                $e->noteMessage();
        }
    } 
}
?>
