<?php
/**
* Returns the result with feast details on request through AJAX or non AJAX requests.
* 
* This file is responsible for serving an AJAX or an ordinary non AJAX client request sent by the 
* Calendar class object. It will serve an XML response in case of AJAX or an XHTML response in case of non AJAX request.
* It will on request send data about details concerning a particular feast.
* 
* @package Calendar
* @subpackage Orthodox calendar
* @category Calendars
* @author Misa Brezanac <brezanac@gmail.com>
* @copyright http://creativecommons.org/licenses/by-nc-sa/3.0/rs/
*/

require_once "config.php";

try {
    /**
    * @desc Performing a thorough checkup of the sent request data.
    */
    
    if(!isset($_GET['day']) || !is_numeric($_GET['day']) || !(isset($_GET['month'])) || !is_numeric($_GET['month']) || !(isset($_GET['year'])) || !is_numeric($_GET['year'])){ 
        /*
        * The data (day, month, year) were not sent or some of it are invalid
        */
        throw new Custom_Exception('details_data_not_present');
    } else { 
        /*
        * The sent data (day, month, year) seems valid.
        */                
        if(!checkdate($_GET['month'], $_GET['day'], $_GET['year'])){
            throw new Custom_Exception('details_date_is_invalid');    
        } else {
            $calendar = new Orthodox_Calendar(CALENDAR_CLASS_ID, $_GET['month'], $_GET['year']);
            if(isset($_GET['ajax']) && $_GET['ajax']){ //requested an AJAX response
                $calendar->renderDetailsToXML($_GET['day']);
            } else {
                $calendar->renderDetails($_GET['day']);   
            }
        }
    }   
} catch (Custom_Exception $e){
    $e->noteMessage();             
}
?>
