<?php
/**
* Returns the result with months overview on request through AJAX or non AJAX requests. 
* 
* This file is responsible for serving an AJAX or an ordinary non AJAX client request sent by the 
* Calendar class object. It will serve an XML response in case of AJAX or an XHTML response in case of non AJAX.
* It will on request send data about the specified months feast table for the given year.
* 
* @package Calendar
* @subpackage Orthodox calendar
* @category Calendars
* @author Misa Brezanac <brezanac@gmail.com>
* @copyright http://creativecommons.org/licenses/by-nc-sa/3.0/rs/
*/

require_once "config.php";

try {
    /**
    * @desc First a thorough checkup of sent form
    */
    if(!isset($_GET['month']) || !isset($_GET['year'])){
        throw new Custom_Exception('form_parameters_non_existant');
    } else if((intval($_GET['year']) < 1901) && (intval($_GET['year']))){
        throw new Custom_Exception('form_parameters_invalid');
    } else { //all OK.
        $calendar = new Orthodox_Calendar(CALENDAR_CLASS_ID, $_GET['month'], $_GET['year']); //instantiation
        $calendar->buildCalendar(); //building
        
        if(isset($_GET['ajax']) && $_GET['ajax']){ //requested an AJAX response
            $calendar->renderCalendarToXML(); //and at the end create an XML response
        } else {
            $calendar->renderCalendar();   
        }
    }
} catch (Custom_Exception $e){
    $e->noteMessage();             
}
?>
